diff --git a/mozilla/content/shared/public/nsXULAtomList.h b/mozilla/content/shared/public/nsXULAtomList.h
index ca28a0401f7..9d5f02fe84e 100644
--- a/mozilla/content/shared/public/nsXULAtomList.h
+++ b/mozilla/content/shared/public/nsXULAtomList.h
@@ -205,7 +205,7 @@ XUL_ATOM(radio, "radio")
XUL_ATOM(radiogroup, "radiogroup")
XUL_ATOM(menulist, "menulist")
XUL_ATOM(menubutton, "menubutton")
-XUL_ATOM(textfield, "textfield")
+XUL_ATOM(textbox, "textbox")
XUL_ATOM(textarea, "textarea")
XUL_ATOM(listbox, "listbox")
XUL_ATOM(tooltip, "tooltip")
diff --git a/mozilla/content/xul/content/src/nsXULAtomList.h b/mozilla/content/xul/content/src/nsXULAtomList.h
new file mode 100644
index 00000000000..2ef3f2e4f8a
--- /dev/null
+++ b/mozilla/content/xul/content/src/nsXULAtomList.h
@@ -0,0 +1,249 @@
+/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
+ *
+ * The contents of this file are subject to the Netscape Public
+ * License Version 1.1 (the "License"); you may not use this file
+ * except in compliance with the License. You may obtain a copy of
+ * the License at http://www.mozilla.org/NPL/
+ *
+ * Software distributed under the License is distributed on an "AS
+ * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
+ * implied. See the License for the specific language governing
+ * rights and limitations under the License.
+ *
+ * The Original Code is mozilla.org code.
+ *
+ * The Initial Developer of the Original Code is Netscape
+ * Communications Corporation. Portions created by Netscape are
+ * Copyright (C) 1999 Netscape Communications Corporation. All
+ * Rights Reserved.
+ *
+ * Original Author: David W. Hyatt (hyatt@netscape.com)
+ *
+ * Contributor(s):
+ */
+
+/******
+
+ This file contains the list of all XUL nsIAtoms and their values
+
+ It is designed to be used as inline input to nsXULAtoms.cpp *only*
+ through the magic of C preprocessing.
+
+ All entires must be enclosed in the macro XUL_ATOM which will have cruel
+ and unusual things done to it
+
+ It is recommended (but not strictly necessary) to keep all entries
+ in alphabetical order
+
+ The first argument to XUL_ATOM is the C++ identifier of the atom
+ The second argument is the string value of the atom
+
+ ******/
+
+
+XUL_ATOM(button, "button")
+XUL_ATOM(spinner, "spinner")
+XUL_ATOM(scrollbar, "scrollbar")
+XUL_ATOM(slider, "slider")
+XUL_ATOM(palettename, "palettename")
+XUL_ATOM(fontpicker, "fontpicker")
+XUL_ATOM(text, "text")
+XUL_ATOM(toolbar, "toolbar")
+XUL_ATOM(toolbaritem, "toolbaritem")
+XUL_ATOM(toolbox, "toolbox")
+XUL_ATOM(image, "image")
+
+ // The tree atoms
+XUL_ATOM(tree, "tree") // The start of a tree view
+XUL_ATOM(treecaption, "treecaption") // The caption of a tree view
+XUL_ATOM(treehead, "treehead") // The header of the tree view
+XUL_ATOM(treerow, "treerow") // A row in the tree view
+XUL_ATOM(treerows, "treerows") // A row in the tree view
+XUL_ATOM(treecell, "treecell") // An item in the tree view
+XUL_ATOM(treeitem, "treeitem") // A cell in the tree view
+XUL_ATOM(treechildren, "treechildren") // The children of an item in the tree view
+XUL_ATOM(treeindentation, "treeindentation") // Specifies that the indentation for the level should occur here.
+XUL_ATOM(allowevents, "allowevents") // Lets events be handled on the cell contents or in menus.
+XUL_ATOM(treecol, "treecol") // A column in the tree view
+XUL_ATOM(treecolgroup, "treecolgroup") // A column group in the tree view
+XUL_ATOM(treecols, "treecols") // A column group in the tree view
+XUL_ATOM(treefoot, "treefoot") // The footer of the tree view
+XUL_ATOM(scrollbarlist, "scrollbarlist") // An atom for internal use by the tree view
+XUL_ATOM(indent, "indent") // indicates that a cell should be indented
+XUL_ATOM(outer, "outer") // indicates that a treechildren is the outermost rowgroup
+XUL_ATOM(sizemode, "sizemode") // when set, measure strings to determine preferred width
+
+XUL_ATOM(open, "open") // Whether or not a menu, tree, etc. is open
+
+XUL_ATOM(outliner, "outliner")
+XUL_ATOM(outlinerbody, "outlinerbody")
+XUL_ATOM(outlinercol, "outlinercol")
+XUL_ATOM(cycler, "cycler")
+XUL_ATOM(primary, "primary")
+XUL_ATOM(current, "current")
+XUL_ATOM(mozoutlinerrow, ":-moz-outliner-row")
+XUL_ATOM(mozoutlinercell, ":-moz-outliner-cell")
+XUL_ATOM(mozoutlinercolumn, ":-moz-outliner-column")
+XUL_ATOM(mozoutlinercelltext, ":-moz-outliner-cell-text")
+XUL_ATOM(mozoutlinertwisty, ":-moz-outliner-twisty")
+XUL_ATOM(mozoutlinerindentation, ":-moz-outliner-indentation")
+
+XUL_ATOM(menubar, "menubar") // An XP menu bar.
+XUL_ATOM(menu, "menu") // Represents an XP menu
+XUL_ATOM(menuitem, "menuitem") // Represents an XP menu item
+XUL_ATOM(menupopup, "menupopup") // The XP menu's children.
+XUL_ATOM(menutobedisplayed, "menutobedisplayed") // The menu is about to be displayed at the next sync w/ frame
+XUL_ATOM(menuactive, "menuactive") // Whether or not a menu is active (without necessarily being open)
+XUL_ATOM(accesskey, "accesskey") // The shortcut key for a menu or menu item
+XUL_ATOM(acceltext, "acceltext") // Text to use for the accelerator
+XUL_ATOM(popupset, "popupset") // Contains popup menus, context menus, and tooltips
+XUL_ATOM(popup, "popup") // The popup for a context menu, popup menu, or tooltip
+XUL_ATOM(menugenerated, "menugenerated") // Internal
+XUL_ATOM(popupanchor, "popupanchor") // Anchor for popups
+XUL_ATOM(popupalign, "popupalign") // Alignment for popups
+XUL_ATOM(ignorekeys, "ignorekeys") // Alignment for popups
+XUL_ATOM(sizetopopup, "sizetopopup") // Whether or not menus size to their popup children (used by menulists)
+
+XUL_ATOM(key, "key") // The key element / attribute
+XUL_ATOM(keycode, "keycode") // The keycode attribute
+XUL_ATOM(keytext, "keytext") // The keytext attribute
+XUL_ATOM(modifiers, "modifiers") // The modifiers attribute
+XUL_ATOM(broadcaster, "broadcaster") // A broadcaster
+XUL_ATOM(observes, "observes") // The observes element
+XUL_ATOM(templateAtom, "template") // A XUL template
+
+XUL_ATOM(progressbar, "progressbar")
+XUL_ATOM(progresstext, "progresstext")
+XUL_ATOM(crop, "crop")
+
+XUL_ATOM(mode, "mode")
+XUL_ATOM(equalsize, "equalsize")
+XUL_ATOM(box, "box")
+XUL_ATOM(hbox, "hbox")
+XUL_ATOM(vbox, "vbox")
+XUL_ATOM(scrollbox, "scrollbox")
+XUL_ATOM(mousethrough, "mousethrough")
+XUL_ATOM(flex, "flex")
+XUL_ATOM(spring, "spring")
+XUL_ATOM(orient, "orient")
+XUL_ATOM(autostretch, "autostretch")
+XUL_ATOM(minwidth, "min-width")
+XUL_ATOM(minheight, "min-height")
+
+XUL_ATOM(autorepeatbutton, "autorepeatbutton")
+
+XUL_ATOM(bulletinboard, "bulletinboard")
+
+XUL_ATOM(titledbox, "titledbox")
+XUL_ATOM(title, "title")
+XUL_ATOM(titledboxContentPseudo, ":titledbox-content")
+
+XUL_ATOM(stack, "stack")
+XUL_ATOM(deck, "deck")
+XUL_ATOM(tabcontrol, "tabcontrol")
+XUL_ATOM(tab, "tab")
+XUL_ATOM(tabpanel, "tabpanel")
+XUL_ATOM(tabpage, "tabpage")
+XUL_ATOM(tabbox, "tabbox")
+XUL_ATOM(index, "index")
+XUL_ATOM(maxpos, "maxpos")
+XUL_ATOM(curpos, "curpos")
+XUL_ATOM(scrollbarbutton, "scrollbarbutton")
+XUL_ATOM(increment, "increment")
+XUL_ATOM(pageincrement, "pageincrement")
+XUL_ATOM(thumb, "thumb")
+XUL_ATOM(toggled, "toggled")
+XUL_ATOM(grippy, "grippy")
+XUL_ATOM(splitter, "splitter")
+XUL_ATOM(collapse, "collapse")
+XUL_ATOM(collapsed, "collapsed")
+XUL_ATOM(resizebefore, "resizebefore")
+XUL_ATOM(resizeafter, "resizeafter")
+XUL_ATOM(state, "state")
+XUL_ATOM(debug, "debug")
+
+XUL_ATOM(fixed, "fixed")
+
+// grid
+XUL_ATOM(grid, "grid")
+XUL_ATOM(rows, "rows")
+XUL_ATOM(columns, "columns")
+XUL_ATOM(row, "row")
+XUL_ATOM(column, "column")
+
+// toolbar & toolbar d&d atoms
+XUL_ATOM(ddDropLocation, "dd-droplocation")
+XUL_ATOM(ddDropLocationCoord, "dd-droplocationcoord")
+XUL_ATOM(ddDropOn, "dd-dropon")
+XUL_ATOM(ddTriggerRepaintSorted, "dd-triggerrepaintsorted")
+XUL_ATOM(ddTriggerRepaintRestore, "dd-triggerrepaintrestore")
+XUL_ATOM(ddTriggerRepaint, "dd-triggerrepaint")
+XUL_ATOM(ddNoDropBetweenRows, "dd-nodropbetweenrows")
+XUL_ATOM(container, "container")
+XUL_ATOM(ddDragDropArea, "dragdroparea")
+XUL_ATOM(ddDropMarker, ":-moz-drop-marker")
+
+XUL_ATOM(widget, "widget")
+XUL_ATOM(window, "window")
+
+XUL_ATOM(iframe, "iframe")
+XUL_ATOM(browser, "browser")
+XUL_ATOM(editor, "editor")
+
+//
+
+XUL_ATOM(checkbox, "checkbox")
+XUL_ATOM(radio, "radio")
+XUL_ATOM(radiogroup, "radiogroup")
+XUL_ATOM(menulist, "menulist")
+XUL_ATOM(menubutton, "menubutton")
+XUL_ATOM(textbox, "textbox")
+XUL_ATOM(textarea, "textarea")
+XUL_ATOM(listbox, "listbox")
+XUL_ATOM(tooltip, "tooltip")
+XUL_ATOM(context, "context")
+XUL_ATOM(style, "style")
+XUL_ATOM(selected, "selected")
+XUL_ATOM(clazz, "class")
+XUL_ATOM(id, "id")
+XUL_ATOM(persist, "persist")
+XUL_ATOM(ref, "ref")
+XUL_ATOM(command, "command")
+XUL_ATOM(value, "value")
+XUL_ATOM(width, "width")
+XUL_ATOM(height, "height")
+XUL_ATOM(left, "left")
+XUL_ATOM(top, "top")
+XUL_ATOM(events, "events")
+XUL_ATOM(targets, "targets")
+XUL_ATOM(uri, "uri")
+XUL_ATOM(empty, "empty")
+XUL_ATOM(textnode, "textnode")
+XUL_ATOM(rule, "rule")
+XUL_ATOM(action, "action")
+XUL_ATOM(containment, "containment")
+XUL_ATOM(flags, "flags")
+XUL_ATOM(Template, "template")
+XUL_ATOM(member, "member")
+XUL_ATOM(conditions, "conditions")
+XUL_ATOM(property, "property")
+XUL_ATOM(instanceOf, "instanceOf")
+XUL_ATOM(xulcontentsgenerated, "xulcontentsgenerated")
+XUL_ATOM(parent, "parent")
+XUL_ATOM(iscontainer, "iscontainer")
+XUL_ATOM(isempty, "isempty")
+XUL_ATOM(bindings, "bindings")
+XUL_ATOM(binding, "binding")
+XUL_ATOM(triple, "triple")
+XUL_ATOM(subject, "subject")
+XUL_ATOM(predicate, "predicate")
+XUL_ATOM(child, "child")
+XUL_ATOM(object, "object")
+XUL_ATOM(tag, "tag")
+XUL_ATOM(content, "content")
+
+XUL_ATOM(blankrow, "blankrow")
+XUL_ATOM(titlebar, "titlebar")
+XUL_ATOM(resizer, "resizer")
+XUL_ATOM(dir, "dir")
+
diff --git a/mozilla/editor/ui/composer/content/editor.xul b/mozilla/editor/ui/composer/content/editor.xul
index 6972950e9b1..fb0cbb6fea7 100644
--- a/mozilla/editor/ui/composer/content/editor.xul
+++ b/mozilla/editor/ui/composer/content/editor.xul
@@ -228,7 +228,7 @@
-
diff --git a/mozilla/editor/ui/composer/content/pref-composer.js b/mozilla/editor/ui/composer/content/pref-composer.js
index cda79d31b05..3f0fb1ede12 100644
--- a/mozilla/editor/ui/composer/content/pref-composer.js
+++ b/mozilla/editor/ui/composer/content/pref-composer.js
@@ -255,7 +255,7 @@ function ChooseImageFile()
dialog.BackgroundImageInput.value = fileName;
ValidateAndPreviewImage(true);
}
- SetTextfieldFocus(dialog.BackgroundImageInput);
+ SetTextboxFocus(dialog.BackgroundImageInput);
}
function ChangeBackgroundImage()
@@ -283,7 +283,7 @@ function ValidateAndPreviewImage(ShowErrorMessage)
backgroundImage = "";
if (ShowErrorMessage)
{
- SetTextfieldFocus(dialog.BackgroundImageInput);
+ SetTextboxFocus(dialog.BackgroundImageInput);
// Tell user about bad image
ShowInputErrorMessage(GetString("MissingImageError"));
}
diff --git a/mozilla/editor/ui/composer/content/pref-composer.xul b/mozilla/editor/ui/composer/content/pref-composer.xul
index 14ae5c501e8..172d490e9fb 100644
--- a/mozilla/editor/ui/composer/content/pref-composer.xul
+++ b/mozilla/editor/ui/composer/content/pref-composer.xul
@@ -54,7 +54,7 @@
-
-
-
-
-
@@ -158,7 +158,7 @@
-
+
diff --git a/mozilla/editor/ui/dialogs/content/EdAdvancedEdit.xul b/mozilla/editor/ui/dialogs/content/EdAdvancedEdit.xul
index 883cdd6b209..84e936a7cd1 100644
--- a/mozilla/editor/ui/dialogs/content/EdAdvancedEdit.xul
+++ b/mozilla/editor/ui/dialogs/content/EdAdvancedEdit.xul
@@ -106,9 +106,9 @@
-
+
-
+
@@ -144,9 +144,9 @@
-
+
-
+
@@ -182,9 +182,9 @@
-
+
-
+
diff --git a/mozilla/editor/ui/dialogs/content/EdColorPicker.js b/mozilla/editor/ui/dialogs/content/EdColorPicker.js
index 680a8023b96..41b00a4d70b 100644
--- a/mozilla/editor/ui/dialogs/content/EdColorPicker.js
+++ b/mozilla/editor/ui/dialogs/content/EdColorPicker.js
@@ -142,7 +142,7 @@ function Startup()
document.getElementById("DefaultColorButton").setAttribute("collapsed","true");
}
- SetTextfieldFocus(dialog.ColorInput);
+ SetTextboxFocus(dialog.ColorInput);
SetWindowLocation();
}
@@ -231,7 +231,7 @@ function ValidateData()
if (NoDefault && !color)
{
ShowInputErrorMessage(GetString("NoColorError"));
- SetTextfieldFocus(dialog.ColorInput);
+ SetTextboxFocus(dialog.ColorInput);
return false;
}
return true;
diff --git a/mozilla/editor/ui/dialogs/content/EdColorPicker.xul b/mozilla/editor/ui/dialogs/content/EdColorPicker.xul
index dc94dca0623..4b886a0c6ee 100644
--- a/mozilla/editor/ui/dialogs/content/EdColorPicker.xul
+++ b/mozilla/editor/ui/dialogs/content/EdColorPicker.xul
@@ -82,7 +82,7 @@
-
+
diff --git a/mozilla/editor/ui/dialogs/content/EdColorProps.js b/mozilla/editor/ui/dialogs/content/EdColorProps.js
index a4497564ba1..305031463cd 100644
--- a/mozilla/editor/ui/dialogs/content/EdColorProps.js
+++ b/mozilla/editor/ui/dialogs/content/EdColorProps.js
@@ -327,7 +327,7 @@ function chooseFile()
dialog.BackgroundImageInput.value = fileName;
ValidateAndPreviewImage(true);
}
- SetTextfieldFocus(dialog.BackgroundImageInput);
+ SetTextboxFocus(dialog.BackgroundImageInput);
}
function ChangeBackgroundImage()
@@ -356,7 +356,7 @@ function ValidateAndPreviewImage(ShowErrorMessage)
backgroundImage = null;
if (ShowErrorMessage)
{
- SetTextfieldFocus(dialog.BackgroundImageInput);
+ SetTextboxFocus(dialog.BackgroundImageInput);
// Tell user about bad image
ShowInputErrorMessage(GetString("MissingImageError"));
}
diff --git a/mozilla/editor/ui/dialogs/content/EdColorProps.xul b/mozilla/editor/ui/dialogs/content/EdColorProps.xul
index f1f19866f1c..4ac3f836723 100644
--- a/mozilla/editor/ui/dialogs/content/EdColorProps.xul
+++ b/mozilla/editor/ui/dialogs/content/EdColorProps.xul
@@ -141,7 +141,7 @@
-
diff --git a/mozilla/editor/ui/dialogs/content/EdDialogCommon.js b/mozilla/editor/ui/dialogs/content/EdDialogCommon.js
index eb106d83fae..dac87fc9688 100644
--- a/mozilla/editor/ui/dialogs/content/EdDialogCommon.js
+++ b/mozilla/editor/ui/dialogs/content/EdDialogCommon.js
@@ -114,22 +114,22 @@ function ValidateNumberString(value, minValue, maxValue)
return "";
}
-function SetTextfieldFocusById(id)
+function SetTextboxFocusById(id)
{
- SetTextfieldFocus(document.getElementById(id));
+ SetTextboxFocus(document.getElementById(id));
}
-function SetTextfieldFocus(textfield)
+function SetTextboxFocus(textbox)
{
- if (textfield)
+ if (textbox)
{
// Select entire contents
// This "fixes" bug 48400 temporarily by
- // not calling "select" on empty textfields
- if (textfield.value.length > 0)
- textfield.select();
+ // not calling "select" on empty textboxes
+ if (textbox.value.length > 0)
+ textbox.select();
- textfield.focus();
+ textbox.focus();
}
}
diff --git a/mozilla/editor/ui/dialogs/content/EdDialogTemplate.js b/mozilla/editor/ui/dialogs/content/EdDialogTemplate.js
index 5833aba6f8a..ee574d263a2 100644
--- a/mozilla/editor/ui/dialogs/content/EdDialogTemplate.js
+++ b/mozilla/editor/ui/dialogs/content/EdDialogTemplate.js
@@ -41,7 +41,7 @@ function Startup()
initDialog();
// SET FOCUS TO FIRST CONTROL
- //SetTextfieldFocus(dialog.editBox);
+ //SetTextboxFocus(dialog.editBox);
SetWindowLocation();
}
diff --git a/mozilla/editor/ui/dialogs/content/EdDictionary.js b/mozilla/editor/ui/dialogs/content/EdDictionary.js
index dd3b37b5654..f23fc41334a 100644
--- a/mozilla/editor/ui/dialogs/content/EdDictionary.js
+++ b/mozilla/editor/ui/dialogs/content/EdDictionary.js
@@ -49,7 +49,7 @@ function Startup()
// Select the supplied word if it is already in the list
SelectWordToAddInList();
- SetTextfieldFocus(WordInput);
+ SetTextboxFocus(WordInput);
SetWindowLocation();
}
diff --git a/mozilla/editor/ui/dialogs/content/EdDictionary.xul b/mozilla/editor/ui/dialogs/content/EdDictionary.xul
index af9e6e6504c..b35950cb6cf 100644
--- a/mozilla/editor/ui/dialogs/content/EdDictionary.xul
+++ b/mozilla/editor/ui/dialogs/content/EdDictionary.xul
@@ -50,7 +50,7 @@
-
+
diff --git a/mozilla/editor/ui/dialogs/content/EdHLineProps.js b/mozilla/editor/ui/dialogs/content/EdHLineProps.js
index 35411f01c10..05f23cb3442 100644
--- a/mozilla/editor/ui/dialogs/content/EdHLineProps.js
+++ b/mozilla/editor/ui/dialogs/content/EdHLineProps.js
@@ -63,7 +63,7 @@ function Startup()
InitDialog()
// SET FOCUS TO FIRST CONTROL
- SetTextfieldFocus(dialog.widthInput);
+ SetTextboxFocus(dialog.widthInput);
// Resize window
window.sizeToContent();
diff --git a/mozilla/editor/ui/dialogs/content/EdHLineProps.xul b/mozilla/editor/ui/dialogs/content/EdHLineProps.xul
index 1dd64f9fa67..9aab4e49857 100644
--- a/mozilla/editor/ui/dialogs/content/EdHLineProps.xul
+++ b/mozilla/editor/ui/dialogs/content/EdHLineProps.xul
@@ -54,13 +54,13 @@
-
+
-
+
diff --git a/mozilla/editor/ui/dialogs/content/EdImageMapHotSpot.js b/mozilla/editor/ui/dialogs/content/EdImageMapHotSpot.js
index f5c6844fdf5..b169d4472aa 100644
--- a/mozilla/editor/ui/dialogs/content/EdImageMapHotSpot.js
+++ b/mozilla/editor/ui/dialogs/content/EdImageMapHotSpot.js
@@ -56,7 +56,7 @@ function Startup()
}
}
- SetTextfieldFocus(dialog.urlInput);
+ SetTextboxFocus(dialog.urlInput);
SetWindowLocation();
}
@@ -87,5 +87,5 @@ function chooseFile()
}
// Put focus into the input field
- SetTextfieldFocus(dialog.urlInput);
-}
\ No newline at end of file
+ SetTextboxFocus(dialog.urlInput);
+}
diff --git a/mozilla/editor/ui/dialogs/content/EdImageMapHotSpot.xul b/mozilla/editor/ui/dialogs/content/EdImageMapHotSpot.xul
index fc60973ea14..c9b220f40ab 100644
--- a/mozilla/editor/ui/dialogs/content/EdImageMapHotSpot.xul
+++ b/mozilla/editor/ui/dialogs/content/EdImageMapHotSpot.xul
@@ -54,7 +54,7 @@
-
+
@@ -62,7 +62,7 @@
-
+
@@ -77,7 +77,7 @@
-
+
diff --git a/mozilla/editor/ui/dialogs/content/EdImageProps.xul b/mozilla/editor/ui/dialogs/content/EdImageProps.xul
index 9841aea28c9..ecbf9e607c7 100644
--- a/mozilla/editor/ui/dialogs/content/EdImageProps.xul
+++ b/mozilla/editor/ui/dialogs/content/EdImageProps.xul
@@ -65,7 +65,7 @@
value = "&locationEditField.label;"
tooltip="aTooltip" tooltiptext="&locationEditField.tooltip;"
/>
-
-
@@ -168,7 +168,7 @@
id = "widthLabel"
for = "widthInput"
value = "&widthEditField.label;" />
-
-
-
@@ -260,7 +260,7 @@
class = "label align-right"
id = "topbottomLabel"
value = "&topBottomEditField.label;"/>
-
@@ -273,7 +273,7 @@
-
diff --git a/mozilla/editor/ui/dialogs/content/EdInsSrc.js b/mozilla/editor/ui/dialogs/content/EdInsSrc.js
index 4b44106f6e2..487f8b26846 100644
--- a/mozilla/editor/ui/dialogs/content/EdInsSrc.js
+++ b/mozilla/editor/ui/dialogs/content/EdInsSrc.js
@@ -45,7 +45,7 @@ function Startup()
// Set initial focus
srcInput.focus();
- // Note: We can't set the caret location in a multiline textfield
+ // Note: We can't set the caret location in a multiline textbox
SetWindowLocation();
}
diff --git a/mozilla/editor/ui/dialogs/content/EdInsSrc.xul b/mozilla/editor/ui/dialogs/content/EdInsSrc.xul
index 11f6b1ee248..993635dfbef 100644
--- a/mozilla/editor/ui/dialogs/content/EdInsSrc.xul
+++ b/mozilla/editor/ui/dialogs/content/EdInsSrc.xul
@@ -47,7 +47,7 @@
-
+
diff --git a/mozilla/editor/ui/dialogs/content/EdInsertTable.js b/mozilla/editor/ui/dialogs/content/EdInsertTable.js
index fc5bc2cc917..55ef0a3fbc5 100644
--- a/mozilla/editor/ui/dialogs/content/EdInsertTable.js
+++ b/mozilla/editor/ui/dialogs/content/EdInsertTable.js
@@ -78,7 +78,7 @@ function Startup()
// Resize window
window.sizeToContent();
- SetTextfieldFocus(dialog.rowsInput);
+ SetTextboxFocus(dialog.rowsInput);
SetWindowLocation();
}
@@ -124,7 +124,7 @@ function ValidateData()
if (columns == "")
{
// Set focus to the offending control
- SetTextfieldFocus(dialog.columnsInput);
+ SetTextboxFocus(dialog.columnsInput);
return false;
}
diff --git a/mozilla/editor/ui/dialogs/content/EdInsertTable.xul b/mozilla/editor/ui/dialogs/content/EdInsertTable.xul
index c595321776c..f49694794f1 100644
--- a/mozilla/editor/ui/dialogs/content/EdInsertTable.xul
+++ b/mozilla/editor/ui/dialogs/content/EdInsertTable.xul
@@ -54,17 +54,17 @@
-
+
-
+
-
+
@@ -76,7 +76,7 @@
-
+
diff --git a/mozilla/editor/ui/dialogs/content/EdLinkProps.js b/mozilla/editor/ui/dialogs/content/EdLinkProps.js
index a53cd9142b0..7db2c400727 100644
--- a/mozilla/editor/ui/dialogs/content/EdLinkProps.js
+++ b/mozilla/editor/ui/dialogs/content/EdLinkProps.js
@@ -206,9 +206,9 @@ function Startup()
// Set initial focus
if (insertLinkAtCaret) {
// We will be using the HREF inputbox, so text message
- SetTextfieldFocus(dialog.linkTextInput);
+ SetTextboxFocus(dialog.linkTextInput);
} else {
- SetTextfieldFocus(dialog.hrefInput);
+ SetTextboxFocus(dialog.hrefInput);
// We will not insert a new link at caret, so remove link text input field
dialog.linkTextInput.setAttribute("hidden","true");
@@ -243,7 +243,7 @@ function chooseFile()
ChangeText();
}
// Put focus into the input field
- SetTextfieldFocus(dialog.hrefInput);
+ SetTextboxFocus(dialog.hrefInput);
}
function FillListboxes()
@@ -430,7 +430,7 @@ function ValidateData()
if (newLinkText.length == 0)
{
ShowInputErrorMessage(GetString("EmptyLinkTextError"));
- SetTextfieldFocus(dialog.linkTextInput);
+ SetTextboxFocus(dialog.linkTextInput);
return false;
}
}
diff --git a/mozilla/editor/ui/dialogs/content/EdLinkProps.xul b/mozilla/editor/ui/dialogs/content/EdLinkProps.xul
index b02c165771d..2d5dec25806 100644
--- a/mozilla/editor/ui/dialogs/content/EdLinkProps.xul
+++ b/mozilla/editor/ui/dialogs/content/EdLinkProps.xul
@@ -48,13 +48,13 @@
-
+
-
+
&RemoveLinkMsg.label;
diff --git a/mozilla/editor/ui/dialogs/content/EdListProps.js b/mozilla/editor/ui/dialogs/content/EdListProps.js
index b4bec9e2966..d52f3f467eb 100644
--- a/mozilla/editor/ui/dialogs/content/EdListProps.js
+++ b/mozilla/editor/ui/dialogs/content/EdListProps.js
@@ -209,7 +209,7 @@ function SelectListType()
break;
case 2:
NewType = "ol";
- SetTextfieldFocus(dialog.StartingNumberInput);
+ SetTextboxFocus(dialog.StartingNumberInput);
break;
case 3:
NewType = "dl";
@@ -242,7 +242,7 @@ function SelectBulletStyle()
if (NumberStyleIndex != index)
{
NumberStyleIndex = index;
- SetTextfieldFocus(dialog.StartingNumberInput);
+ SetTextboxFocus(dialog.StartingNumberInput);
}
}
}
diff --git a/mozilla/editor/ui/dialogs/content/EdListProps.xul b/mozilla/editor/ui/dialogs/content/EdListProps.xul
index 8cafd0c298a..e988e1fb273 100644
--- a/mozilla/editor/ui/dialogs/content/EdListProps.xul
+++ b/mozilla/editor/ui/dialogs/content/EdListProps.xul
@@ -67,7 +67,7 @@
-
+
&startingHelp.label;
diff --git a/mozilla/editor/ui/dialogs/content/EdNamedAnchorProps.js b/mozilla/editor/ui/dialogs/content/EdNamedAnchorProps.js
index 17137f5ac96..39cc2cbddb2 100644
--- a/mozilla/editor/ui/dialogs/content/EdNamedAnchorProps.js
+++ b/mozilla/editor/ui/dialogs/content/EdNamedAnchorProps.js
@@ -74,7 +74,7 @@ function Startup()
InitDialog();
- SetTextfieldFocus(nameInput);
+ SetTextboxFocus(nameInput);
SetWindowLocation();
}
@@ -114,7 +114,7 @@ function ValidateData()
if (!name)
{
ShowInputErrorMessage(GetString("MissingAnchorNameError"));
- SetTextfieldFocus(nameInput);
+ SetTextboxFocus(nameInput);
return false;
} else {
// Replace spaces with "_" and strip other characters
@@ -125,7 +125,7 @@ function ValidateData()
if (originalName != name && AnchorNameExists(name))
{
ShowInputErrorMessage(GetString("DuplicateAnchorNameError").replace(/%name%/,name));
- SetTextfieldFocus(nameInput);
+ SetTextboxFocus(nameInput);
return false;
}
globalElement.setAttribute("name",name);
diff --git a/mozilla/editor/ui/dialogs/content/EdNamedAnchorProps.xul b/mozilla/editor/ui/dialogs/content/EdNamedAnchorProps.xul
index 76972874c32..b27ef02b103 100644
--- a/mozilla/editor/ui/dialogs/content/EdNamedAnchorProps.xul
+++ b/mozilla/editor/ui/dialogs/content/EdNamedAnchorProps.xul
@@ -48,7 +48,7 @@
-
diff --git a/mozilla/editor/ui/dialogs/content/EdPageProps.js b/mozilla/editor/ui/dialogs/content/EdPageProps.js
index 5399c1bfdd7..ff7993ca544 100644
--- a/mozilla/editor/ui/dialogs/content/EdPageProps.js
+++ b/mozilla/editor/ui/dialogs/content/EdPageProps.js
@@ -92,7 +92,7 @@ dump(", lastmod date="+lastmoddate+"\n");
InitDialog();
- SetTextfieldFocus(dialog.TitleInput);
+ SetTextboxFocus(dialog.TitleInput);
SetWindowLocation();
}
@@ -112,7 +112,7 @@ function InitDialog()
dialog.DescriptionInput.value = descriptionElement.getAttribute("content");
}
-function TextfieldChanged(ID)
+function TextboxChanged(ID)
{
switch(ID)
{
diff --git a/mozilla/editor/ui/dialogs/content/EdPageProps.xul b/mozilla/editor/ui/dialogs/content/EdPageProps.xul
index cb014f48836..29918defbed 100644
--- a/mozilla/editor/ui/dialogs/content/EdPageProps.xul
+++ b/mozilla/editor/ui/dialogs/content/EdPageProps.xul
@@ -58,15 +58,15 @@
-
+
-
+
-
+
diff --git a/mozilla/editor/ui/dialogs/content/EdSpellCheck.js b/mozilla/editor/ui/dialogs/content/EdSpellCheck.js
index 7cd915fa9df..9cffec0c463 100644
--- a/mozilla/editor/ui/dialogs/content/EdSpellCheck.js
+++ b/mozilla/editor/ui/dialogs/content/EdSpellCheck.js
@@ -248,7 +248,7 @@ function SetWidgetsForMisspelledWord()
DoEnabling();
if (MisspelledWord)
- SetTextfieldFocus(dialog.ReplaceWordInput);
+ SetTextboxFocus(dialog.ReplaceWordInput);
}
function CheckWord()
diff --git a/mozilla/editor/ui/dialogs/content/EdSpellCheck.xul b/mozilla/editor/ui/dialogs/content/EdSpellCheck.xul
index 47ab0cd7364..73f218fc221 100644
--- a/mozilla/editor/ui/dialogs/content/EdSpellCheck.xul
+++ b/mozilla/editor/ui/dialogs/content/EdSpellCheck.xul
@@ -57,7 +57,7 @@
-
+
diff --git a/mozilla/editor/ui/dialogs/content/EdTableProps.xul b/mozilla/editor/ui/dialogs/content/EdTableProps.xul
index 7bf81f7e28f..253ee9c595b 100644
--- a/mozilla/editor/ui/dialogs/content/EdTableProps.xul
+++ b/mozilla/editor/ui/dialogs/content/EdTableProps.xul
@@ -61,11 +61,11 @@
-
+
-
+
@@ -75,7 +75,7 @@
-
+
@@ -87,17 +87,17 @@
-
+
-
+
-
+
@@ -178,12 +178,14 @@
-
+
-
+
@@ -194,11 +196,13 @@
-
+
-
+
diff --git a/mozilla/editor/ui/dialogs/content/EditorSaveAsCharset.js b/mozilla/editor/ui/dialogs/content/EditorSaveAsCharset.js
index fc1aaf49f3f..80abfbc5b24 100644
--- a/mozilla/editor/ui/dialogs/content/EditorSaveAsCharset.js
+++ b/mozilla/editor/ui/dialogs/content/EditorSaveAsCharset.js
@@ -69,7 +69,7 @@ function Startup()
helpTextParent.appendChild(helpText);
// SET FOCUS TO FIRST CONTROL
- SetTextfieldFocus(dialog.TitleInput);
+ SetTextboxFocus(dialog.TitleInput);
LoadAvailableCharSets();
initDone = true;
diff --git a/mozilla/editor/ui/dialogs/content/EditorSaveAsCharset.xul b/mozilla/editor/ui/dialogs/content/EditorSaveAsCharset.xul
index 002a69827d2..e0f452fed28 100644
--- a/mozilla/editor/ui/dialogs/content/EditorSaveAsCharset.xul
+++ b/mozilla/editor/ui/dialogs/content/EditorSaveAsCharset.xul
@@ -51,7 +51,7 @@
-
+
diff --git a/mozilla/embedding/browser/chrome/content/mini-nav.xul b/mozilla/embedding/browser/chrome/content/mini-nav.xul
index 005156e1842..d2b683cb100 100644
--- a/mozilla/embedding/browser/chrome/content/mini-nav.xul
+++ b/mozilla/embedding/browser/chrome/content/mini-nav.xul
@@ -77,7 +77,7 @@ Contributor(s): ______________________________________. -->
-
diff --git a/mozilla/extensions/inspector/resources/content/extensions/treeEditable.xml b/mozilla/extensions/inspector/resources/content/extensions/treeEditable.xml
index 9d761bbeeab..6901352851f 100644
--- a/mozilla/extensions/inspector/resources/content/extensions/treeEditable.xml
+++ b/mozilla/extensions/inspector/resources/content/extensions/treeEditable.xml
@@ -63,7 +63,7 @@
this.mEditingItem = item;
editor.focus();
- // if it proves to be a textfield... select it's text
+ // if it proves to be a textbox... select it's text
if (editor.select) editor.select();
]]>
@@ -86,7 +86,7 @@
@@ -157,4 +157,4 @@
-
\ No newline at end of file
+
diff --git a/mozilla/extensions/inspector/resources/content/jsutil/xul/inFormManager.js b/mozilla/extensions/inspector/resources/content/jsutil/xul/inFormManager.js
index 5c8279b6cee..371cdc2ca98 100644
--- a/mozilla/extensions/inspector/resources/content/jsutil/xul/inFormManager.js
+++ b/mozilla/extensions/inspector/resources/content/jsutil/xul/inFormManager.js
@@ -2,7 +2,7 @@
* inFormManager -------------------------------------------------
* Manages the reading and writing of forms via simple maps of
* attribute/value pairs. A "form" is simply a XUL window which
-* contains "form widgets" such as textfields and menulists.
+* contains "form widgets" such as textboxes and menulists.
* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
* REQUIRED IMPORTS:
****************************************************************/
@@ -54,7 +54,7 @@ var inFormManager =
}
},
- read_textfield: function(aEl)
+ read_textbox: function(aEl)
{
return aEl.value;
},
@@ -79,7 +79,7 @@ var inFormManager =
return aEl.getAttribute("color");
},
- write_textfield: function(aEl, aValue)
+ write_textbox: function(aEl, aValue)
{
aEl.setAttribute("value", aValue);
},
diff --git a/mozilla/extensions/inspector/resources/content/prefs/pref-inspector.xul b/mozilla/extensions/inspector/resources/content/prefs/pref-inspector.xul
index 655cc1c6d70..b4f85391bda 100644
--- a/mozilla/extensions/inspector/resources/content/prefs/pref-inspector.xul
+++ b/mozilla/extensions/inspector/resources/content/prefs/pref-inspector.xul
@@ -50,7 +50,7 @@
-
@@ -58,7 +58,7 @@
-
@@ -66,7 +66,7 @@
-
diff --git a/mozilla/extensions/inspector/resources/content/search/modules/findFiles/dialog.xul b/mozilla/extensions/inspector/resources/content/search/modules/findFiles/dialog.xul
index afbf2d8954a..4b71bcad58a 100644
--- a/mozilla/extensions/inspector/resources/content/search/modules/findFiles/dialog.xul
+++ b/mozilla/extensions/inspector/resources/content/search/modules/findFiles/dialog.xul
@@ -20,11 +20,11 @@
-
+
-
+
diff --git a/mozilla/extensions/inspector/resources/content/search/modules/junkImgs/dialog.xul b/mozilla/extensions/inspector/resources/content/search/modules/junkImgs/dialog.xul
index 3db8de9e3b3..26705e98e4f 100644
--- a/mozilla/extensions/inspector/resources/content/search/modules/junkImgs/dialog.xul
+++ b/mozilla/extensions/inspector/resources/content/search/modules/junkImgs/dialog.xul
@@ -21,13 +21,13 @@
&junkImgsDescription;
-
+
diff --git a/mozilla/extensions/transformiix/resources/buster/buster.xul b/mozilla/extensions/transformiix/resources/buster/buster.xul
index 0fdcfffff19..46a703079ae 100644
--- a/mozilla/extensions/transformiix/resources/buster/buster.xul
+++ b/mozilla/extensions/transformiix/resources/buster/buster.xul
@@ -43,13 +43,13 @@
-
+
-
+
diff --git a/mozilla/extensions/vixen/resources/content/palette/vxPalette.js b/mozilla/extensions/vixen/resources/content/palette/vxPalette.js
index eec4e4a689e..38de8777212 100644
--- a/mozilla/extensions/vixen/resources/content/palette/vxPalette.js
+++ b/mozilla/extensions/vixen/resources/content/palette/vxPalette.js
@@ -37,12 +37,12 @@ var vxPalette =
this.insertSingleElement("button", attributes, values, "Insert Button " + nElements);
},
- insertTextFieldElement: function (aType)
+ insertTextboxElement: function (aType)
{
- var nElements = this.incrementElementCount("textfield");
+ var nElements = this.incrementElementCount("textbox");
var attributes = ["value", "id"];
- var values = ["Textfield " + nElements, "textfield_" + nElements];
- this.insertSingleElement("textfield", attributes, values, "Insert Textfield " + nElements);
+ var values = ["Textbox " + nElements, "textbox" + nElements];
+ this.insertSingleElement("textbox", attributes, values, "Insert Textbox " + nElements);
},
insertRadioGroup: function ()
diff --git a/mozilla/extensions/vixen/resources/content/palette/vxPalette.xul b/mozilla/extensions/vixen/resources/content/palette/vxPalette.xul
index b3820ef04f4..0977e5e6b15 100644
--- a/mozilla/extensions/vixen/resources/content/palette/vxPalette.xul
+++ b/mozilla/extensions/vixen/resources/content/palette/vxPalette.xul
@@ -22,8 +22,8 @@
-
+
diff --git a/mozilla/extensions/vixen/resources/content/vfdCommands.xul b/mozilla/extensions/vixen/resources/content/vfdCommands.xul
index 01fbef97f4b..0d320e5d580 100644
--- a/mozilla/extensions/vixen/resources/content/vfdCommands.xul
+++ b/mozilla/extensions/vixen/resources/content/vfdCommands.xul
@@ -55,8 +55,8 @@
oncommand="nsVFD.insertMenuElement('combobox');"/>
-
+
-
+
-
+
-
+
-
+
-
+
-
+
diff --git a/mozilla/extensions/wallet/editor/WalletUrlspecific.xul b/mozilla/extensions/wallet/editor/WalletUrlspecific.xul
index 32f5ef590b8..7e7b7dbd5ab 100644
--- a/mozilla/extensions/wallet/editor/WalletUrlspecific.xul
+++ b/mozilla/extensions/wallet/editor/WalletUrlspecific.xul
@@ -47,8 +47,8 @@
if (colonIndex != -1) {
var rows = document.getElementById("rows");
var row = document.createElementNS("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul", "row");
- var text1 = document.createElementNS("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul", "textfield");
- var text2 = document.createElementNS("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul", "textfield");
+ var text1 = document.createElementNS("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul", "textbox");
+ var text2 = document.createElementNS("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul", "textbox");
var spring = document.createElementNS("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul", "spring");
var menuList = document.createElementNS("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul", "menulist");
var menuPopup = document.createElementNS("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul", "menupopup");
diff --git a/mozilla/extensions/wallet/editor/WalletViewer.js b/mozilla/extensions/wallet/editor/WalletViewer.js
index 45988a7c1e9..8ee6935daec 100644
--- a/mozilla/extensions/wallet/editor/WalletViewer.js
+++ b/mozilla/extensions/wallet/editor/WalletViewer.js
@@ -216,12 +216,12 @@ nsWalletViewer.prototype =
function Append(thisMenuList) {
- /* Note: we always want a zero-length textfield so the user
+ /* Note: we always want a zero-length textbox so the user
* can start typing in a new value. So we need to determine
- * if user has started typing into the zero-length textfield
+ * if user has started typing into the zero-length textbox
* in which case it's time to create yet another zero-length
* one. We also need to determine if user has removed all
- * text in a textfield in which case that textfield needs to
+ * text in a textbox in which case that textbox needs to
* be removed
*/
@@ -232,7 +232,7 @@ nsWalletViewer.prototype =
}
thisMenuItem.setAttribute('value',thisMenuList.value);
- /* determine previous size of textfield */
+ /* determine previous size of textbox */
var len = Number(thisMenuItem.getAttribute("len"));
/* update previous size */
diff --git a/mozilla/extensions/wallet/editor/resources/content/WalletUrlspecific.xul b/mozilla/extensions/wallet/editor/resources/content/WalletUrlspecific.xul
index 32f5ef590b8..7e7b7dbd5ab 100644
--- a/mozilla/extensions/wallet/editor/resources/content/WalletUrlspecific.xul
+++ b/mozilla/extensions/wallet/editor/resources/content/WalletUrlspecific.xul
@@ -47,8 +47,8 @@
if (colonIndex != -1) {
var rows = document.getElementById("rows");
var row = document.createElementNS("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul", "row");
- var text1 = document.createElementNS("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul", "textfield");
- var text2 = document.createElementNS("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul", "textfield");
+ var text1 = document.createElementNS("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul", "textbox");
+ var text2 = document.createElementNS("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul", "textbox");
var spring = document.createElementNS("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul", "spring");
var menuList = document.createElementNS("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul", "menulist");
var menuPopup = document.createElementNS("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul", "menupopup");
diff --git a/mozilla/extensions/wallet/editor/resources/content/WalletViewer.js b/mozilla/extensions/wallet/editor/resources/content/WalletViewer.js
index 45988a7c1e9..8ee6935daec 100644
--- a/mozilla/extensions/wallet/editor/resources/content/WalletViewer.js
+++ b/mozilla/extensions/wallet/editor/resources/content/WalletViewer.js
@@ -216,12 +216,12 @@ nsWalletViewer.prototype =
function Append(thisMenuList) {
- /* Note: we always want a zero-length textfield so the user
+ /* Note: we always want a zero-length textbox so the user
* can start typing in a new value. So we need to determine
- * if user has started typing into the zero-length textfield
+ * if user has started typing into the zero-length textbox
* in which case it's time to create yet another zero-length
* one. We also need to determine if user has removed all
- * text in a textfield in which case that textfield needs to
+ * text in a textbox in which case that textbox needs to
* be removed
*/
@@ -232,7 +232,7 @@ nsWalletViewer.prototype =
}
thisMenuItem.setAttribute('value',thisMenuList.value);
- /* determine previous size of textfield */
+ /* determine previous size of textbox */
var len = Number(thisMenuItem.getAttribute("len"));
/* update previous size */
diff --git a/mozilla/extensions/wallet/resources/content/pref-wallet.xul b/mozilla/extensions/wallet/resources/content/pref-wallet.xul
index bd0692e4e03..fbd601c06d6 100644
--- a/mozilla/extensions/wallet/resources/content/pref-wallet.xul
+++ b/mozilla/extensions/wallet/resources/content/pref-wallet.xul
@@ -65,7 +65,7 @@
for="walletServer"
value="&walletServer.label;"
accesskey="&walletServer.accesskey;"/>
-
-
+
diff --git a/mozilla/layout/xul/content/src/nsXULAtomList.h b/mozilla/layout/xul/content/src/nsXULAtomList.h
new file mode 100644
index 00000000000..9c156f09de8
--- /dev/null
+++ b/mozilla/layout/xul/content/src/nsXULAtomList.h
@@ -0,0 +1,210 @@
+/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
+ *
+ * The contents of this file are subject to the Netscape Public
+ * License Version 1.1 (the "License"); you may not use this file
+ * except in compliance with the License. You may obtain a copy of
+ * the License at http://www.mozilla.org/NPL/
+ *
+ * Software distributed under the License is distributed on an "AS
+ * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
+ * implied. See the License for the specific language governing
+ * rights and limitations under the License.
+ *
+ * The Original Code is mozilla.org code.
+ *
+ * The Initial Developer of the Original Code is Netscape
+ * Communications Corporation. Portions created by Netscape are
+ * Copyright (C) 1999 Netscape Communications Corporation. All
+ * Rights Reserved.
+ *
+ * Original Author: David W. Hyatt (hyatt@netscape.com)
+ *
+ * Contributor(s):
+ */
+
+/******
+
+ This file contains the list of all XUL nsIAtoms and their values
+
+ It is designed to be used as inline input to nsXULAtoms.cpp *only*
+ through the magic of C preprocessing.
+
+ All entires must be enclosed in the macro XUL_ATOM which will have cruel
+ and unusual things done to it
+
+ It is recommended (but not strictly necessary) to keep all entries
+ in alphabetical order
+
+ The first argument to XUL_ATOM is the C++ identifier of the atom
+ The second argument is the string value of the atom
+
+ ******/
+
+
+XUL_ATOM(button, "button")
+XUL_ATOM(spinner, "spinner")
+XUL_ATOM(scrollbar, "scrollbar")
+XUL_ATOM(slider, "slider")
+XUL_ATOM(palettename, "palettename")
+XUL_ATOM(fontpicker, "fontpicker")
+XUL_ATOM(text, "text")
+XUL_ATOM(toolbar, "toolbar")
+XUL_ATOM(toolbaritem, "toolbaritem")
+XUL_ATOM(toolbox, "toolbox")
+XUL_ATOM(image, "image")
+
+ // The tree atoms
+XUL_ATOM(tree, "tree") // The start of a tree view
+XUL_ATOM(treecaption, "treecaption") // The caption of a tree view
+XUL_ATOM(treehead, "treehead") // The header of the tree view
+XUL_ATOM(treerow, "treerow") // A row in the tree view
+XUL_ATOM(treerows, "treerows") // A row in the tree view
+XUL_ATOM(treecell, "treecell") // An item in the tree view
+XUL_ATOM(treeitem, "treeitem") // A cell in the tree view
+XUL_ATOM(treechildren, "treechildren") // The children of an item in the tree view
+XUL_ATOM(treeindentation, "treeindentation") // Specifies that the indentation for the level should occur here.
+XUL_ATOM(allowevents, "allowevents") // Lets events be handled on the cell contents or in menus.
+XUL_ATOM(treecol, "treecol") // A column in the tree view
+XUL_ATOM(treecolgroup, "treecolgroup") // A column group in the tree view
+XUL_ATOM(treecols, "treecols") // A column group in the tree view
+XUL_ATOM(treefoot, "treefoot") // The footer of the tree view
+XUL_ATOM(scrollbarlist, "scrollbarlist") // An atom for internal use by the tree view
+XUL_ATOM(indent, "indent") // indicates that a cell should be indented
+XUL_ATOM(outer, "outer") // indicates that a treechildren is the outermost rowgroup
+XUL_ATOM(sizemode, "sizemode") // when set, measure strings to determine preferred width
+
+XUL_ATOM(open, "open") // Whether or not a menu, tree, etc. is open
+XUL_ATOM(focus, "focus")
+
+XUL_ATOM(outliner, "outliner")
+XUL_ATOM(outlinerbody, "outlinerbody")
+XUL_ATOM(outlinercol, "outlinercol")
+
+XUL_ATOM(cycler, "cycler")
+XUL_ATOM(primary, "primary")
+XUL_ATOM(current, "current")
+XUL_ATOM(mozoutlinerrow, ":-moz-outliner-row")
+XUL_ATOM(mozoutlinercell, ":-moz-outliner-cell")
+XUL_ATOM(mozoutlinercolumn, ":-moz-outliner-column")
+XUL_ATOM(mozoutlinercelltext, ":-moz-outliner-cell-text")
+XUL_ATOM(mozoutlinertwisty, ":-moz-outliner-twisty")
+XUL_ATOM(mozoutlinerindentation, ":-moz-outliner-indentation")
+XUL_ATOM(mozoutlinerline, ":-moz-outliner-line")
+
+XUL_ATOM(menubar, "menubar") // An XP menu bar.
+XUL_ATOM(menu, "menu") // Represents an XP menu
+XUL_ATOM(menuitem, "menuitem") // Represents an XP menu item
+XUL_ATOM(menupopup, "menupopup") // The XP menu's children.
+XUL_ATOM(menutobedisplayed, "menutobedisplayed") // The menu is about to be displayed at the next sync w/ frame
+XUL_ATOM(menuactive, "menuactive") // Whether or not a menu is active (without necessarily being open)
+XUL_ATOM(accesskey, "accesskey") // The shortcut key for a menu or menu item
+XUL_ATOM(acceltext, "acceltext") // Text to use for the accelerator
+XUL_ATOM(popupset, "popupset") // Contains popup menus, context menus, and tooltips
+XUL_ATOM(popup, "popup") // The popup for a context menu, popup menu, or tooltip
+XUL_ATOM(menugenerated, "menugenerated") // Internal
+XUL_ATOM(popupanchor, "popupanchor") // Anchor for popups
+XUL_ATOM(popupalign, "popupalign") // Alignment for popups
+XUL_ATOM(ignorekeys, "ignorekeys") // Alignment for popups
+XUL_ATOM(sizetopopup, "sizetopopup") // Whether or not menus size to their popup children (used by menulists)
+
+XUL_ATOM(key, "key") // The key element / attribute
+XUL_ATOM(keycode, "keycode") // The keycode attribute
+XUL_ATOM(keytext, "keytext") // The keytext attribute
+XUL_ATOM(modifiers, "modifiers") // The modifiers attribute
+XUL_ATOM(broadcaster, "broadcaster") // A broadcaster
+XUL_ATOM(observes, "observes") // The observes element
+XUL_ATOM(templateAtom, "template") // A XUL template
+
+XUL_ATOM(progressbar, "progressbar")
+XUL_ATOM(crop, "crop")
+
+XUL_ATOM(mode, "mode")
+XUL_ATOM(equalsize, "equalsize")
+XUL_ATOM(box, "box")
+XUL_ATOM(hbox, "hbox")
+XUL_ATOM(vbox, "vbox")
+XUL_ATOM(scrollbox, "scrollbox")
+XUL_ATOM(mousethrough, "mousethrough")
+XUL_ATOM(flex, "flex")
+XUL_ATOM(spring, "spring")
+XUL_ATOM(orient, "orient")
+XUL_ATOM(autostretch, "autostretch")
+XUL_ATOM(minwidth, "min-width")
+XUL_ATOM(minheight, "min-height")
+
+XUL_ATOM(autorepeatbutton, "autorepeatbutton")
+
+XUL_ATOM(bulletinboard, "bulletinboard")
+
+XUL_ATOM(titledbox, "titledbox")
+XUL_ATOM(title, "title")
+XUL_ATOM(titledboxContentPseudo, ":titledbox-content")
+
+XUL_ATOM(stack, "stack")
+XUL_ATOM(deck, "deck")
+XUL_ATOM(tabcontrol, "tabcontrol")
+XUL_ATOM(tab, "tab")
+XUL_ATOM(tabpanel, "tabpanel")
+XUL_ATOM(tabpage, "tabpage")
+XUL_ATOM(tabbox, "tabbox")
+XUL_ATOM(index, "index")
+XUL_ATOM(maxpos, "maxpos")
+XUL_ATOM(curpos, "curpos")
+XUL_ATOM(scrollbarbutton, "scrollbarbutton")
+XUL_ATOM(increment, "increment")
+XUL_ATOM(pageincrement, "pageincrement")
+XUL_ATOM(thumb, "thumb")
+XUL_ATOM(toggled, "toggled")
+XUL_ATOM(grippy, "grippy")
+XUL_ATOM(splitter, "splitter")
+XUL_ATOM(collapse, "collapse")
+XUL_ATOM(collapsed, "collapsed")
+XUL_ATOM(resizebefore, "resizebefore")
+XUL_ATOM(resizeafter, "resizeafter")
+XUL_ATOM(state, "state")
+XUL_ATOM(debug, "debug")
+
+XUL_ATOM(fixed, "fixed")
+
+// grid
+XUL_ATOM(grid, "grid")
+XUL_ATOM(rows, "rows")
+XUL_ATOM(columns, "columns")
+XUL_ATOM(row, "row")
+XUL_ATOM(column, "column")
+
+// toolbar & toolbar d&d atoms
+XUL_ATOM(ddDropLocation, "dd-droplocation")
+XUL_ATOM(ddDropLocationCoord, "dd-droplocationcoord")
+XUL_ATOM(ddDropOn, "dd-dropon")
+XUL_ATOM(ddTriggerRepaintSorted, "dd-triggerrepaintsorted")
+XUL_ATOM(ddTriggerRepaintRestore, "dd-triggerrepaintrestore")
+XUL_ATOM(ddTriggerRepaint, "dd-triggerrepaint")
+XUL_ATOM(ddNoDropBetweenRows, "dd-nodropbetweenrows")
+XUL_ATOM(container, "container")
+XUL_ATOM(ddDragDropArea, "dragdroparea")
+XUL_ATOM(ddDropMarker, ":-moz-drop-marker")
+
+XUL_ATOM(widget, "widget")
+XUL_ATOM(window, "window")
+
+XUL_ATOM(iframe, "iframe")
+XUL_ATOM(browser, "browser")
+XUL_ATOM(editor, "editor")
+
+//
+
+XUL_ATOM(checkbox, "checkbox")
+XUL_ATOM(radio, "radio")
+XUL_ATOM(radiogroup, "radiogroup")
+XUL_ATOM(menulist, "menulist")
+XUL_ATOM(menubutton, "menubutton")
+XUL_ATOM(textbox, "textbox")
+XUL_ATOM(textarea, "textarea")
+XUL_ATOM(listbox, "listbox")
+
+XUL_ATOM(blankrow, "blankrow")
+XUL_ATOM(titlebar, "titlebar")
+XUL_ATOM(resizer, "resizer")
+XUL_ATOM(dir, "dir")
+
diff --git a/mozilla/mailnews/addrbook/prefs/resources/content/pref-addressing.xul b/mozilla/mailnews/addrbook/prefs/resources/content/pref-addressing.xul
index 05d1f4895e3..dd35c742bd5 100644
--- a/mozilla/mailnews/addrbook/prefs/resources/content/pref-addressing.xul
+++ b/mozilla/mailnews/addrbook/prefs/resources/content/pref-addressing.xul
@@ -12,7 +12,10 @@
diff --git a/mozilla/editor/ui/dialogs/content/EdAdvancedEdit.js b/mozilla/editor/ui/dialogs/content/EdAdvancedEdit.js
index 57c36318731..c4b653b65ec 100644
--- a/mozilla/editor/ui/dialogs/content/EdAdvancedEdit.js
+++ b/mozilla/editor/ui/dialogs/content/EdAdvancedEdit.js
@@ -248,7 +248,7 @@ function doSelect(e)
cell.setAttribute("class","FocusSelected");
input.setAttribute("class","FocusSelected");
- SetTextfieldFocus(input);
+ SetTextboxFocus(input);
}
}
*/
@@ -263,7 +263,7 @@ function AddTreeItem ( name, value, treekidsId, attArray, valueCaseFunc )
var attrcell = document.createElementNS ( XUL_NS, "treecell" );
attrcell.setAttribute( "class", "propertylist" );
attrcell.setAttribute( "value", name );
// Modify treerow selection to better show focus in textfield
treeitem.setAttribute( "class", "ae-selection");
treerow.appendChild ( attrcell );
@@ -289,27 +289,27 @@ function CreateCellWithField( name, value )
if (!valCell) return null;
valCell.setAttribute ( "class", "value propertylist" );
valCell.setAttribute ( "allowevents", "true" );
- var valField = document.createElementNS ( XUL_NS, "textfield" );
+ var valField = document.createElementNS ( XUL_NS, "textbox" );
if ( name ) valField.setAttribute ( "id", name );
if (!valField) return null;
if ( value ) valField.setAttribute ( "value", value );
valField.setAttribute ( "flex", "1" );
valField.setAttribute ( "class", "plain" );
- valField.setAttribute ( "onfocus", "SelectItemWithTextfield(\""+name+"\")");
+ valField.setAttribute ( "onfocus", "SelectItemWithTextbox(\""+name+"\")");
valField.setAttribute ( "allowevents", "true");
valCell.appendChild ( valField );
return valCell;
}
-function SelectItemWithTextfield(id)
+function SelectItemWithTextbox(id)
{
- var textfield = document.getElementById(id);
- if (textfield)
+ var textbox = document.getElementById(id);
+ if (textbox)
{
- var treeItem = textfield.parentNode.parentNode.parentNode;
+ var treeItem = textbox.parentNode.parentNode.parentNode;
if (treeItem)
{
// Prevent SelectTreeItem() from setting selection to entire textfield
gSelecting = true;
treeItem.parentNode.parentNode.selectItem(treeItem);
gSelecting = false;
@@ -317,20 +317,20 @@ function SelectItemWithTextfield(id)
}
}
// When a "name" treecell is selected, shift focus to the textfield
function SelectTreeItem(tree)
{
// Prevent infinite loop -- SetTextfieldFocusById triggers recursive call
if (gSelecting) return;
gSelecting = true;
if (tree && tree.selectedItems && tree.selectedItems.length)
{
- // 2nd cell (value column) contains the textfield
- var textfieldCell = tree.selectedItems[0].firstChild.firstChild.nextSibling;
- if (textfieldCell)
+ // 2nd cell (value column) contains the textbox
+ var textboxCell = tree.selectedItems[0].firstChild.firstChild.nextSibling;
+ if (textboxCell)
{
// Select its contents and set focus
- SetTextfieldFocusById(textfieldCell.firstChild.id);
+ SetTextboxFocusById(textboxCell.firstChild.id);
}
}
gSelecting = false;
@@ -263,7 +263,7 @@ function AddTreeItem ( name, value, treekidsId, attArray, valueCaseFunc )
attrcell.setAttribute( "class", "propertylist" );
attrcell.setAttribute( "value", name );
- // Modify treerow selection to better show focus in textfield
+ // Modify treerow selection to better show focus in textbox
treeitem.setAttribute( "class", "ae-selection");
treerow.appendChild ( attrcell );
@@ -289,27 +289,27 @@ function CreateCellWithField( name, value )
if (treeItem)
{
- // Prevent SelectTreeItem() from setting selection to entire textfield
+ // Prevent SelectTreeItem() from setting selection to entire textbox
gSelecting = true;
treeItem.parentNode.parentNode.selectItem(treeItem);
@@ -317,20 +317,20 @@ function SelectItemWithTextfield(id)
}
}
-// When a "name" treecell is selected, shift focus to the textfield
+// When a "name" treecell is selected, shift focus to the textbox
function SelectTreeItem(tree)
{
@@ -317,20 +317,20 @@ function SelectItemWithTextfield(id)
function SelectTreeItem(tree)
{
- // Prevent infinite loop -- SetTextfieldFocusById triggers recursive call
+ // Prevent infinite loop -- SetTextboxFocusById triggers recursive call
if (gSelecting) return;
gSelecting = true;
diff --git a/mozilla/editor/ui/dialogs/content/EdImageProps.js b/mozilla/editor/ui/dialogs/content/EdImageProps.js
index a161cfbf52a..66cc886a23a 100644
--- a/mozilla/editor/ui/dialogs/content/EdImageProps.js
+++ b/mozilla/editor/ui/dialogs/content/EdImageProps.js
@@ -174,7 +174,7 @@ function Startup()
// Initialize widgets with image attributes in the case where the entire dialog isn't visible
onMoreFewerImage(); // this call will initialize all widgets if entire dialog is visible
- SetTextfieldFocus(dialog.srcInput);
+ SetTextboxFocus(dialog.srcInput);
SetWindowLocation();
}
@@ -257,7 +257,7 @@ function chooseFile()
}
GetImageFromURL();
// Put focus into the input field
- SetTextfieldFocus(dialog.srcInput);
+ SetTextboxFocus(dialog.srcInput);
}
function GetImageFromURL()
@@ -403,7 +403,7 @@ function onMoreFewerImage()
// Show the "Advanced Edit" button on same line as "More Properties"
dialog.AdvancedEditButton.setAttribute("collapsed","false");
dialog.AdvancedEditButton2.setAttribute("collapsed","true");
// Weird caret appearing when we collapse, so force focus to URL textfield
dialog.srcInput.focus();
}
else
@@ -573,7 +573,7 @@ function ValidateData()
if (doAltTextError && !alt)
{
ShowInputErrorMessage(GetString("NoAltText"));
- SetTextfieldFocus(dialog.altTextInput);
+ SetTextboxFocus(dialog.altTextInput);
doAltTextError = false;
return false;
}
@@ -600,7 +600,7 @@ function ValidateData()
{
if ( !SeeMore )
onMoreFewerImage();
- SetTextfieldFocus(dialog.widthInput);
+ SetTextboxFocus(dialog.widthInput);
return false;
}
if (isPercentWidth)
@@ -612,7 +612,7 @@ function ValidateData()
{
if ( !SeeMore )
onMoreFewerImage();
- SetTextfieldFocus(dialog.heightInput);
+ SetTextboxFocus(dialog.heightInput);
return false;
}
if (isPercentHeight)
@@ -403,7 +403,7 @@ function onMoreFewerImage()
dialog.AdvancedEditButton.setAttribute("collapsed","false");
dialog.AdvancedEditButton2.setAttribute("collapsed","true");
- // Weird caret appearing when we collapse, so force focus to URL textfield
+ // Weird caret appearing when we collapse, so force focus to URL textbox
dialog.srcInput.focus();
}
diff --git a/mozilla/editor/ui/dialogs/content/EdTableProps.js b/mozilla/editor/ui/dialogs/content/EdTableProps.js
index d919599b7b9..f92c1f2baa7 100644
--- a/mozilla/editor/ui/dialogs/content/EdTableProps.js
+++ b/mozilla/editor/ui/dialogs/content/EdTableProps.js
@@ -237,7 +237,7 @@ function Startup()
dialog.NextButton.setAttribute("disabled", "true");
}
- // User can change these via textfields
+ // User can change these via textboxes
newRowCount = rowCount;
newColCount = colCount;
@@ -254,7 +254,7 @@ function Startup()
if (currentPanel == CellPanel)
dialog.SelectionList.focus();
else
- SetTextfieldFocus(dialog.TableRowsInput);
+ SetTextboxFocus(dialog.TableRowsInput);
SetWindowLocation();
}
@@ -550,7 +550,7 @@ function ChangeSelection(newType)
DoCellSelection();
SetSelectionButtons();
- // Enable/Disable appropriate span textfields
+ // Enable/Disable appropriate span textboxes
SetSpanEnable();
// Note: globalCellElement should still be a clone of CellElement
@@ -814,7 +814,7 @@ function ValidateNumber(inputWidgetID, listWidget, minVal, maxVal, element, attN
SwitchPanel(validatePanel);
// Error - shift to offending input widget
- SetTextfieldFocus(inputWidget);
+ SetTextboxFocus(inputWidget);
error = true;
}
else
@@ -968,16 +968,16 @@ function ValidateData()
return true;
}
-function ChangeCellTextfield(textfieldID)
+function ChangeCellTextbox(textboxID)
{
// Filter input for just integers
- forceInteger(textfieldID);
+ forceInteger(textboxID);
if (currentPanel == CellPanel)
CellDataChanged = true;
}
// Call this when a textfield or menulist is changed
// so the checkbox is automatically set
function SetCheckbox(checkboxID)
{
@@ -989,10 +989,10 @@ function SetCheckbox(checkboxID)
CellDataChanged = true;
}
-function ChangeIntTextfield(textfieldID, checkboxID)
+function ChangeIntTextbox(textboxID, checkboxID)
{
// Filter input for just integers
- forceInteger(textfieldID);
+ forceInteger(textboxID);
// Set associated checkbox
SetCheckbox(checkboxID);
@@ -968,16 +968,16 @@ function ValidateData()
CellDataChanged = true;
}
-// Call this when a textfield or menulist is changed
+// Call this when a textbox or menulist is changed
// so the checkbox is automatically set
function SetCheckbox(checkboxID)